@@ -146,7 +146,7 @@ class Filter:
 class OatClient:
     
     base_url: str
-    compilation_setting: CompilationSetting = field(default_factory=lambda: CompilationSetting.INSTANT)
+    compilation_setting: CompilationSetting = field(default_factory=lambda: CompilationSetting.ON_DEMAND)
 
     # Buffer all function calls until compile is called
     _buffer: Dict[str, FunctionCall] = field(default_factory=dict)
@@ -289,7 +289,7 @@ class OatClient:
         self._id_map.update({id: id for id in ids})
         return ids
     
-    def set_gelineq(self, coefficients: Dict[str, int], bias: int) -> str:
+    def set_gelineq(self, coefficients: Dict[str, int], bias: int, alias: str | None = None) -> str:
         fn_data = FunctionCall(
             fn="set_gelineq",
             args={
@@ -297,7 +297,8 @@ class OatClient:
                     {"id": self._resolve_id(k), "coefficient": v}
                     for k, v in coefficients.items()
                 ],
-                "bias": bias
+                "bias": bias,
+                "alias": alias
             },
         )
         fn_hash = fn_data.hash()
@@ -310,24 +311,26 @@ class OatClient:
 
         return fn_hash
     
-    def set_atleast(self, references: List[str], value: int) -> str:
+    def set_atleast(self, references: List[str], value: int, alias: str | None = None) -> str:
         return self.set_gelineq(
             coefficients={r: 1 for r in references},
-            bias=-value
+            bias=-value,
+            alias=alias
         )
     
-    def set_atmost(self, references: List[str], value: int) -> str:
+    def set_atmost(self, references: List[str], value: int, alias: str | None = None) -> str:
         return self.set_gelineq(
             coefficients={r: -1 for r in references},
-            bias=value
+            bias=value,
+            alias=alias
         )
     
-    def set_equal(self, references: List[str], value: Union[int, str]) -> str:
+    def set_equal(self, references: List[str], value: Union[int, str], alias: str | None = None) -> str:
         if isinstance(value, int):
             return self.set_and([
                 self.set_atleast(references, value),
                 self.set_atmost(references, value)
-            ])
+            ], alias=alias)
         else:
             return self.set_and([
                 self.set_gelineq(
@@ -338,46 +341,49 @@ class OatClient:
                     coefficients={value: 1, **{r: -1 for r in references}},
                     bias=0
                 ),
-            ])
+            ], alias=alias)
 
-    def set_and(self, references: List[str]) -> str:
+    def set_and(self, references: List[str], alias: str | None = None) -> str:
         return self.set_gelineq(
             coefficients={r: 1 for r in references},
-            bias=-len(references)
+            bias=-len(references),
+            alias=alias
         )
     
-    def set_or(self, references: List[str]) -> str:
+    def set_or(self, references: List[str], alias: str | None = None) -> str:
         return self.set_gelineq(
             coefficients={r: 1 for r in references},
-            bias=-1
+            bias=-1,
+            alias=alias
         )
     
-    def set_xor(self, references: List[str]) -> str:
+    def set_xor(self, references: List[str], alias: str | None = None) -> str:
         return self.set_and([
             self.set_or(references),
             self.set_atmost(references, 1)
-        ])
+        ], alias=alias)
 
-    def set_not(self, references: List[str]) -> str:
+    def set_not(self, references: List[str], alias: str | None = None) -> str:
         return self.set_gelineq(
             coefficients={r: -1 for r in references},
-            bias=0
+            bias=0,
+            alias=alias
         )
 
-    def set_imply(self, lhs: str, rhs: str) -> str:
+    def set_imply(self, lhs: str, rhs: str, alias: str | None = None) -> str:
         return self.set_or([
             self.set_gelineq(
                 coefficients={lhs: -1},
                 bias=0
             ),
             rhs
-        ])
+        ], alias=alias)
     
-    def set_equiv(self, lhs: str, rhs: str) -> str:
+    def set_equiv(self, lhs: str, rhs: str, alias: str | None = None) -> str:
         return self.set_or([
             self.set_gelineq({lhs: -1, rhs: -1}, bias=0),
             self.set_and([rhs, lhs])
-        ])
+        ], alias=alias)
     
     def get_node_ids(self, filter: Optional[dict] = None) -> List[dict]:
         """
@@ -460,7 +466,52 @@ class OatClient:
             }
         )
         return self._execute_fn(fn_data)
-    
+
+    def get_alias(self, id: str) -> Optional[str]:
+        """Get the primary alias for a node.
+
+        Args:
+            id: Node ID
+
+        Returns:
+            The alias string or None if no alias is set
+        """
+        fn_data = FunctionCall(
+            fn="get_alias",
+            args={"id": self._resolve_id(id)}
+        )
+        return self._execute_fn(fn_data)
+
+    def get_aliases_from_id(self, id: str) -> List[str]:
+        """Get all aliases pointing to a specific node.
+
+        Args:
+            id: Node ID
+
+        Returns:
+            List of alias strings pointing to this node
+        """
+        fn_data = FunctionCall(
+            fn="get_aliases_from_id",
+            args={"id": self._resolve_id(id)}
+        )
+        return self._execute_fn(fn_data)
+
+    def get_ids_from_aliases(self, aliases: List[str]) -> List[str]:
+        """Get node IDs from a list of aliases.
+
+        Args:
+            aliases: List of alias strings
+
+        Returns:
+            List of node IDs corresponding to the aliases (only includes aliases that exist)
+        """
+        fn_data = FunctionCall(
+            fn="get_ids_from_aliases",
+            args={"aliases": aliases}
+        )
+        return self._execute_fn(fn_data)
+
     def solve(self, roots: List[str], objectives: List[Dict[str, int]], assume: Dict[str, complex] = {}, maximize: bool = True) -> List[dict]:
         result = self._execute_fns([
             FunctionCall(
@@ -525,4 +576,12 @@ class OatClient:
                 "id": self._resolve_id(id)
             }
         )
-        self._execute_fn(fn_data)
\ No newline at end of file
+        self._execute_fn(fn_data)
+
+
+# Export public API
+__all__ = [
+    'OatClient',
+    'CompilationSetting',
+    'Filter',
+]
\ No newline at end of file
